@@ -1,11 +1,14 @@
 ﻿
 
 
-__version__ = "0.2022.2.4"
+__version__ = "0.2022.2.6.1"
+__api_version__ = 2
 
 
 
 from .SpoolInfo import SpoolInfo
 from .Spooler import Spooler
 from .Packer import Packer
+from .Packer1 import Packer1
 from .Unpacker import Unpacker
+from .Unpacker1 import Unpacker1
\ No newline at end of file
